@@ -7,6 +7,7 @@
 #include <pulse/pulseaudio.h>
 #include <QtDBus>
 #include <QDBusMessage>
+#include <QLabel>
 
 class Widget : public QWidget
 {
@@ -21,6 +22,7 @@ public:
     bool transmitterActive;
     QPushButton *button1;
     QPushButton *button2;
+    QLabel *freqLabel;
 
 private slots:
     void toggleMegaphone();
@@ -31,6 +33,8 @@ private slots:
     void toggleTransmitter();
     void onTransmitterChanged(QString, const QString &msg2, QStringList);
     void callIncoming();
+    uint getFrequency();
+    void setFreqLabel();
 
 };
 
